@@ -49,8 +49,8 @@ public:
     CommandLineArguments(QCommandLineParser &parser)
         : QObject()
     {
-        m_pageId = parser.value("page-id");
-        m_pageName = parser.value("page-name");
+        m_pageId = parser.value(QStringLiteral("page-id"));
+        m_pageName = parser.value(QStringLiteral("page-name"));
     }
 
     QVariant aboutData() const
@@ -67,7 +67,7 @@ class SessionManager : public QObject
 {
     Q_OBJECT
 public:
-    SessionManager(QObject *parent);
+    explicit SessionManager(QObject *parent);
 
 private:
     QString m_pageId;
@@ -99,7 +99,7 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("plasma-systemmonitor");
 
-    KAboutData aboutData{/* componentName */ "plasma-systemmonitor",
+    KAboutData aboutData{/* componentName */ QStringLiteral("plasma-systemmonitor"),
                          /* displayName */ i18n("System Monitor"),
                          /* version */ PROJECT_VERSION,
                          /* shortDescription */ i18n("An application for monitoring system resources"),
@@ -144,7 +144,7 @@ int main(int argc, char **argv)
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QStringLiteral(":/main.qml"));
+    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, []() {
         if (!qApp->topLevelWindows().isEmpty()) {
